# sage_setup: distribution = sagemath-environment
r"""
Feature for testing the presence of ``info``, from GNU Info
"""

from . import Executable


class Info(Executable):
    r"""
    A :class:`~sage.features.Feature` describing the presence of :ref:`info <spkg_info>`.

    EXAMPLES::

        sage: from sage.features.info import Info
        sage: Info()
        Feature('info')
    """
    def __init__(self):
        r"""
        TESTS::

            sage: from sage.features.info import Info
            sage: isinstance(Info(), Info)
            True
        """
        Executable.__init__(self, 'info', executable='info',
                            spkg='info', type='standard')


def all_features():
    return [Info()]



# sage_setup: distribution = sagemath-environment
r"""
Feature for testing the presence of Sloane Online Encyclopedia of Integer Sequences
"""

# ****************************************************************************
#       Copyright (C) 2024 Kwankyu Lee <ekwankyu@gmail.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#                  https://www.gnu.org/licenses/
# ****************************************************************************

from . import Feature


class SloaneOEIS(Feature):
    r"""
    A :class:`~sage.features.Feature` which describes the presence of
    the Sloane Online Encyclopedia of Integer Sequences.

    EXAMPLES::

        sage: from sage.features.sloane_database import SloaneOEIS
        sage: bool(SloaneOEIS().is_present())  # optional - sloane_database
        True
    """
    def __init__(self):
        r"""
        TESTS::

            sage: from sage.features.sloane_database import SloaneOEIS
            sage: isinstance(SloaneOEIS(), SloaneOEIS)
            True
        """
        Feature.__init__(self, name='sloane_database',
                         description='Sloane Online Encyclopedia of Integer Sequences')

    def _is_present(self):
        r"""
        Return whether the database is available.

        EXAMPLES::

            sage: from sage.features.sloane_database import SloaneOEIS
            sage: bool(SloaneOEIS().is_present())  # optional - !sloane_database
            False
        """
        try:
            from sage.databases.sloane import SloaneEncyclopedia
        except ImportError:
            return False
        return SloaneEncyclopedia.is_installed()


def all_features():
    return [SloaneOEIS()]



# sage_setup: distribution = sagemath-environment
r"""
Feature for testing the presence of ``phitigra``
"""

# *****************************************************************************
#       Copyright (C) 2022 Jean-Florent Raymond
#
#  Distributed under the terms of the GNU General Public License (GPL)
#  as published by the Free Software Foundation; either version 2 of
#  the License, or (at your option) any later version.
#                  https://www.gnu.org/licenses/
# *****************************************************************************

from . import PythonModule


class Phitigra(PythonModule):
    r"""
    A :class:`sage.features.Feature` describing the presence of :ref:`phitigra <spkg_phitigra>`.

    Phitigra is provided by an optional package in the Sage distribution.

    EXAMPLES::

        sage: from sage.features.phitigra import Phitigra
        sage: Phitigra().is_present()                     # optional - phitigra
        FeatureTestResult('phitigra', True)
    """
    def __init__(self):
        r"""
        TESTS::

            sage: from sage.features.phitigra import Phitigra
            sage: isinstance(Phitigra(), Phitigra)
            True
        """
        PythonModule.__init__(self, 'phitigra', spkg='phitigra')


def all_features():
    return [Phitigra()]



# sage_setup: distribution = sagemath-environment
# Sage version information for Python scripts
# This file is auto-generated by the update-version script, do not edit!
version = '10.6.31.rc3'
date = '2025-10-22'
banner = 'passagemath version 10.6.31.rc3, Release Date: 2025-10-22'
